import sys
import os
import asyncio

# Add the local src directory to Python path
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '../src')))

from glide_sdk import GlideClient
from glide_sdk.services.kyc_match import KycMatchPayload

async def main():
    # Initialize the client
    glide = GlideClient()
    
    # Create a kyc match client for a specific phone number
    kyc_match_client = await glide.kyc_match.for_user(
        phone_number="+555123456789"
    )
    
    # Create the payload
    payload = KycMatchPayload(
        phoneNumber="+555123456789",
        idDocument="66666666q",
        name="Federica Sanchez Arjona",
        giventName="Federica",
        familyName="Sanchez Arjona",
        nameKanaHankaku="federica",
        nameKanaZenkaku="Ｆｅｄｅｒｉｃａ",
        middleNames="Sanchez",
        familyNameAtBirth="YYYY",
        address="Tokyo-to Chiyoda-ku Iidabashi 3-10-10",
        streetName="Nicolas Salmeron",
        streetNumber=4,
        postalCode=1028460,
        region="Tokyo",
        locality="ZZZZ",
        country="Japan",
        houseNumberExtension="VVVV",
        birthdate="1978-08-22",
        email="abc@example.com",
        gender="male"
    )
    
    # Check if consent is required
    if kyc_match_client.requires_consent:
        print(f"Please visit this URL to provide consent: {kyc_match_client.get_consent_url()}")
        # Wait for user consent
        await kyc_match_client.poll_and_wait_for_session()
    
    # Perform KYC match
    result = await kyc_match_client.match(payload)
    print(result)

if __name__ == "__main__":
    asyncio.run(main()) 