import sys
import os
import asyncio
import httpx
import time

# Add the local src directory to Python path
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '../src')))

from glide_sdk import GlideClient

PHONE_NUMBER = "+555123456789"

async def main():
    await magic_auth_client_example()
    # await magic_auth_server_example()


async def magic_auth_client_example():
    # Initialize the client (will use .env)
    glide = GlideClient()
    
    # Start magic auth process
    magic_auth_start_response = await glide.magic_auth.start_auth(
        phone_number=PHONE_NUMBER
    )
    print('Magic auth start response:', magic_auth_start_response)
    
    # Get token from auth URL
    async with httpx.AsyncClient(follow_redirects=True) as client:
        res = await client.get(magic_auth_start_response.authUrl)
        token = res.headers.get("token")
    
    # Verify the auth
    magic_auth_check_response = await glide.magic_auth.verify_auth(
        phone_number=PHONE_NUMBER,
        token=token
    )
    print('Magic auth response:', magic_auth_check_response)

async def magic_auth_server_example():
    # Initialize the client (will use .env)
    glide = GlideClient()
    
    try:
        # Start magic auth process
        magic_auth_start_response = await glide.magic_auth.start_server_auth(
            phone_number=PHONE_NUMBER
        )
        print('Magic auth start server auth response:', magic_auth_start_response)
        
        # Get token from auth URL
        async with httpx.AsyncClient(follow_redirects=True) as client:
            res = await client.get(magic_auth_start_response.authUrl)

        # Wait Until the auth is completed or timeout
        timeout = 120
        start_time = time.time()
        magic_auth_check_response = None
        
        while True:
            magic_auth_check_response = await glide.magic_auth.check_server_auth(
                session_id=magic_auth_start_response.sessionId
            )
            print('Magic auth check server auth response:', magic_auth_check_response)
            
            if magic_auth_check_response.verified:
                print("Authentication successful!")
                break
                
            if time.time() - start_time > timeout:
                raise Exception("Auth timed out")
                
            await asyncio.sleep(10)

    except Exception as e:
        print(f"Error: {str(e)}")
        print(f"Error type: {type(e)}")
        raise

if __name__ == "__main__":
    asyncio.run(main()) 